pyramid_zcml
============

pyramid_zcml is a package which provides ZCML (Zope Configuration Markup
Language) directives for all "configurator" methods available in the `Pyramid
<https://trypyramid.com/>`_ web framework.

See `http://docs.pylonsproject.org/projects/pyramid_zcml/en/latest/
<http://docs.pylonsproject.org/projects/pyramid_zcml/en/latest/>`_ for
detailed documentation.
